# -*- coding: utf-8 -*-
__author__ = "Paul Schifferer <dm@sweetrpg.com>"
"""Types.
"""

CONTRIBUTION = 'contribution'
PERSON = 'person'
PUBLISHER = 'publisher'
REVIEW = 'review'
STUDIO = 'studio'
SYSTEM = 'system'
VOLUME = 'volume'
